@@ -4,4 +4,9 @@
 
 __author__ = "Denis Kuznetsov"
 __email__ = "kuznetsov.den.p@gmail.com"
-__version__ = "0.2.1"
+__version__ = "0.3.0"
+
+
+import nest_asyncio
+
+nest_asyncio.apply()
