@@ -1,8 +1,9 @@
 """
 Types
 -----
-This module contains two special types.
-One is used for the messenger interface to client interaction, the other to the polling loop control.
+The Types module contains two special types that are used throughout the `DFF Messengers`.
+The first type is used for the messenger interface to client interaction and the second one
+to control the polling loop.
 """
 from typing import Callable, Any, Hashable, Awaitable
 from typing_extensions import TypeAlias
@@ -13,7 +14,7 @@ from dff.script import Context
 PipelineRunnerFunction: TypeAlias = Callable[[Any, Hashable], Awaitable[Context]]
 """
 A function type for messenger_interface-to-client interaction.
-Accepts anything (user input) and hashable vaklue (current dialog id), returns string (answer from pipeline).
+Accepts anything (user input) and hashable value (current context id), returns string (answer from pipeline).
 """
 
 
